@@ -215,14 +215,13 @@ class ValidationResultsTableContentBlockRenderer(ExpectationStringRenderer):
                 df = pd.DataFrame({
                     "bin_min": bins_x1,
                     "bin_max": bins_x2,
-                    "weights": weights,
+                    "fraction": weights,
                 })
-                df.weights *= 100
-        
+
                 bars = alt.Chart(df).mark_bar().encode(
                     x='bin_min:O',
                     x2='bin_max:O',
-                    y="weights:Q"
+                    y="fraction:Q"
                 ).properties(width=width, height=height, autosize="fit")
                 chart = bars.to_json()
             elif evr["result"]["details"]["observed_partition"].get("values"):
@@ -230,13 +229,12 @@ class ValidationResultsTableContentBlockRenderer(ExpectationStringRenderer):
     
                 df = pd.DataFrame({
                     "values": values,
-                    "weights": weights
+                    "fraction": weights
                 })
-                df.weights *= 100
-    
+
                 bars = alt.Chart(df).mark_bar().encode(
                     x='values:N',
-                    y="weights:Q"
+                    y="fraction:Q"
                 ).properties(width=width, height=height, autosize="fit")
                 chart = bars.to_json()
             
